@@ -9,7 +9,7 @@ from __future__ import division
 from __future__ import print_function
 
 # Internal
-from .lib import get_birth_death_rates, get_ages, is_binary, get_short_branches, get_tip_labels, crown_capture_probability, edge_iter, get_new_times
+from .lib import get_birth_death_rates, get_ages, is_binary, get_short_branches, get_tip_labels, crown_capture_probability, edge_iter, get_new_times, ensure_tree_node_depths
 from . import fastmrca
 
 # Python standard library
@@ -122,7 +122,7 @@ def fill_new_taxa(namespace, node, new_taxa, times, stem=False, excluded_nodes=N
         node = graft_node(node, new_node, stem)
 
     if list(get_short_branches(node)):
-        logger.warning("{} short branches detected".format(len(list(get_short_branches(node)))))
+        logger.info("{} short branches detected".format(len(list(get_short_branches(node)))))
 
     return node
 
@@ -222,7 +222,7 @@ def create_clade(namespace, species, ages):
     # Lock the child of the seed node so that things can still attach to the stem of this new clade
     lock_clade(tree.seed_node.child_nodes()[0])
     if list(get_short_branches(tree.seed_node)):
-        logger.warning("{} short branches detected".format(len(list(get_short_branches(tree.seed_node)))))
+        logger.info("{} short branches detected".format(len(list(get_short_branches(tree.seed_node)))))
     return tree
 
 
@@ -312,7 +312,7 @@ def run_precalcs(taxonomy_tree, backbone_tree, min_ccp=0.8, min_extant=3, yule=F
     root_mrca = backbone_tree.mrca(leafset_bitmask=extant_bitmask)
     root_birth, root_death = get_birth_death_rates(root_mrca, len(root_mrca.leaf_nodes()) / len(all_possible_tips), yule)
 
-    with click.progressbar(taxonomy_tree.preorder_internal_node_iter(exclude_seed_node=True), label="Rates", length=nnodes, show_pos=True, item_show_func=lambda x: x.label if x else None) as progress:
+    with click.progressbar(taxonomy_tree.preorder_internal_node_iter(exclude_seed_node=True), width=12, label="Rates", length=nnodes, show_pos=True, item_show_func=lambda x: x.label if x else None) as progress:
         for node in progress:
             # updates global mrca_rates as a side effect
             process_node(backbone_tree, backbone_bitmask, all_possible_tips, node, min_ccp, root_birth, root_death, yule)
@@ -330,16 +330,6 @@ def update_tree_view(tree):
     return get_tip_labels(tree)
 
 
-def compute_node_depths(tree):
-    res = dict()
-    for leaf in tree.leaf_node_iter():
-        cnt = 0
-        for anc in leaf.ancestor_iter():
-            if anc.label:
-                cnt += 1
-        res[leaf.taxon.label] = cnt
-    return res
-
 
 @click.command()
 @click.option("--taxonomy", help="a taxonomy tree", type=click.File("r"), required=True)
@@ -372,25 +362,17 @@ def main(taxonomy, backbone, outgroups, output, min_ccp, verbose, yule):
     tn.is_mutable = False
 
     # Check for equal depth of all nodes
-    node_depths = compute_node_depths(taxonomy)
-    stats = collections.defaultdict(int)
-    for v in node_depths.values():
-        stats[v] += 1
-    if len(stats) > 1:
-        logger.warning("The tips of your taxonomy tree do not have equal numbers of ranked clades in their ancestor chain:")
-        for k in sorted(stats.keys()):
-            logger.warning("* {} tips have {} ranked ancestors".format(stats[k], k))
-        logger.warning("If TACT-added tips are intruding into otherwise-monophyletic clades this should be corrected.")
+    msg = ensure_tree_node_depths(taxonomy)
+    if msg:
+        logger.warning(msg)
 
     logger.info("Reading backbone".format(backbone))
 
     try:
         tree = dendropy.Tree.get_from_stream(backbone, schema="newick", rooting="default-rooted", taxon_namespace=tn)
     except dendropy.utility.error.ImmutableTaxonNamespaceError as e:
-        logger.error("DendroPy error: {}".format(e.message))
+        logger.error("DendroPy error: {}".format(e))
         print("""
-DendroPy error: {}
-
 This usually indicates your backbone has species that are not present in your
 taxonomy. Outgroups not in the taxonomy can be excluded with the argument:
 
@@ -399,7 +381,11 @@ taxonomy. Outgroups not in the taxonomy can be excluded with the argument:
 For more details, run:
 
     tact_add_taxa --help
-""".format(e.message))
+""")
+        sys.exit(1)
+
+    if not is_binary(tree):
+        logger.error("Backbone tree is not binary!")
         sys.exit(1)
 
     tree.encode_bipartitions()
@@ -427,6 +413,7 @@ For more details, run:
     bar = click.progressbar(label="TACT",
                             length=len(all_possible_tips) - initial_length,
                             show_pos=True,
+                            width=12,
                             item_show_func=lambda x: x)
 
     def bar_update():
